Changelog
=========

There's a frood who really knows where his towel is.

1.0a2 (2016-10-06)
------------------

- Fix exception on ``AMPView`` when content has no lead image.
  [hvelarde]


1.0a1 (2016-10-06)
------------------

- Initial release.
